@@ -2,6 +2,7 @@
  * bibcore.c
  *
  * Copyright (c) Chris Putnam 2005-2020
+ * Copyright (c) Georgi N. Boshnakov 2020-2022
  *
  * Source code released under the GPL version 2
  *
@@ -477,7 +478,10 @@ read_refs( FILE *fp, bibl *bin, char *filename, param *p )
 			goto out;
 		}
 		if ( p->processf( ref, reference.data, filename, refnum+1, p )){
-			ret = bibl_addref( bin, ref );
+		  			ret = bibl_addref( bin, ref );
+					
+					// fields_report_stderr(ref); // Georgi, for tests
+				
 			if ( ret!=BIBL_OK ) {
 				bibl_free( bin );
 				fields_delete( ref );
@@ -588,7 +592,7 @@ bibl_addcount( bibl *b )
 		n = fields_find( ref, "REFNUM", LEVEL_MAIN );
 		if ( n==FIELDS_NOTFOUND ) continue;
 
-		sprintf( buf, "_%ld", i+1 );
+		snprintf( buf, 512, "_%ld", i+1 );
 		str_strcatc( fields_value( ref, n, FIELDS_STRP_NOUSE ), buf );
 		if ( str_memerr( fields_value( ref, n, FIELDS_STRP_NOUSE ) ) ) {
 			return BIBL_ERR_MEMERR;
@@ -637,7 +641,7 @@ generate_citekey( fields *f, long nref )
 	}
 
 	else {
-		sprintf( buf, "ref%ld", nref );
+	  snprintf( buf, 100, "ref%ld", nref );
 		str_strcpyc( &citekey, buf );
 	}
 
@@ -805,16 +809,23 @@ convert_refs( bibl *bin, char *fname, bibl *bout, param *p )
 	fields *rin, *rout;
 	long i;
 
-	for ( i=0; i<bin->n; ++i ) {
+	// REprintf("convert_refs: in convert_refs!\n");
 
+	// REprintf("convert_refs: bib->n = %d\n", bin->n);
+	for ( i=0; i<bin->n; ++i ) {
+	        // REprintf("convert_refs: i = %d\n", i);
 		rin = bin->ref[i];
 
+		// fields_report_stderr( rin );  // Testing only !!!!!!!!!!!!!!!1
+
 		rout = fields_new();
 		if ( !rout ) return BIBL_ERR_MEMERR;
 
 		if ( p->typef ) reftype = p->typef( rin, fname, i+1, p );
 
+		// REprintf("convert_refs: before p->convertf\n");
 		status = p->convertf( rin, rout, reftype, p );
+		// REprintf("convert_refs: after p->convertf\n");
 		if ( status!=BIBL_OK ) return status;
 
 		if ( p->all ) {
@@ -828,6 +839,7 @@ convert_refs( bibl *bin, char *fname, bibl *bout, param *p )
 		if ( status!=BIBL_OK ) return status;
 	}
 
+	// REprintf("convert_refs: end of convert_refs!\n");
 	return BIBL_OK;
 }
 
@@ -837,6 +849,7 @@ bibl_read( bibl *b, FILE *fp, char *filename, param *p )
 	int status = BIBL_OK;
 	param read_params;
 	bibl bin;
+	// REprintf("(bibl_read) in bibl_read!\n");
 
 	if ( !b )  return BIBL_ERR_BADINPUT;
 	if ( !fp ) return BIBL_ERR_BADINPUT;
@@ -847,7 +860,12 @@ bibl_read( bibl *b, FILE *fp, char *filename, param *p )
 		return BIBL_ERR_BADINPUT;
 	}
 
+	// REprintf("(bibl_read) after bibl_illegalinmode\n");
+	
 	status = bibl_setreadparams( &read_params, p );
+
+	// REprintf("(bibl_read) after bibl_setreadparams\n");
+	
 	if ( status!=BIBL_OK ) {
 	  if ( debug_set( p ) ) report_params( "bibl_read", p );
 		return status;
@@ -859,6 +877,9 @@ bibl_read( bibl *b, FILE *fp, char *filename, param *p )
 
 	bibl_init( &bin );
 
+
+	// REprintf("(bibl_read) before read_refs\n");
+	
 	status = read_refs( fp, &bin, filename, &read_params );
 	if ( status!=BIBL_OK ) {
 	  if ( debug_set( &read_params ) ) report_params( "bibl_read", &read_params );
@@ -866,11 +887,11 @@ bibl_read( bibl *b, FILE *fp, char *filename, param *p )
 		return status;
 	}
 
-	// Georgi: for testing
-//   REprintf("bibl_read: (after(read_refs)\n");
-//   for(long i = 0; i < bin.n; ++i) {
-//     fields_report_stderr( bin.ref[i] );
-//   }
+	// // Georgi: for testing
+	// REprintf("bibl_read: (after(read_refs)\n");
+	// for(long i = 0; i < bin.n; ++i) {
+	//   fields_report_stderr( bin.ref[i] );
+	// }
 
 	if ( debug_set( &read_params ) ) { 
 		bibl_verbose( &bin, "raw_input", "for bibl_read" );
@@ -882,12 +903,11 @@ bibl_read( bibl *b, FILE *fp, char *filename, param *p )
 		if ( debug_set( &read_params ) ) bibl_verbose( &bin, "post_clean_refs", "for bibl_read" );
 	}
 	
-//   REprintf("bibl_read: (after(clean_refs)\n");
-//   // Georgi: for testing
-//   for(long i = 0; i < bin.n; ++i) {
-//     fields_report_stderr( bin.ref[i] );
-//   }
-
+	// // Georgi: for testing
+	// REprintf("bibl_read: (after(clean_refs)\n");
+	// for(long i = 0; i < bin.n; ++i) {
+	//   fields_report_stderr( bin.ref[i] );
+	// }
 
 	if ( ( !read_params.output_raw ) || ( read_params.output_raw & BIBL_RAW_WITHCHARCONVERT ) ) {
 	  	status = bibl_fixcharsets( &bin, &read_params );
@@ -895,25 +915,31 @@ bibl_read( bibl *b, FILE *fp, char *filename, param *p )
 		if ( debug_set( &read_params ) ) bibl_verbose( &bin, "post_fixcharsets", "for bibl_read" );
 	}
 
-//   REprintf("bibl_read: (after(bibl_fixcharsets)\n");
-//   // Georgi: for testing
-//   for(long i = 0; i < bin.n; ++i) {
-//     fields_report_stderr( bin.ref[i] );
-//   }
+	// REprintf("bibl_read: (after(bibl_fixcharsets)\n");
+	// Georgi: for testing
+	// for(long i = 0; i < bin.n; ++i) {
+	//   fields_report_stderr( bin.ref[i] );
+	// }
 
 	if ( !read_params.output_raw ) {
+	        // REprintf("bibl_read: before convert_refs; read_params.output_raw is FALSE\n");
 		status = convert_refs( &bin, filename, b, &read_params );
 		if ( status!=BIBL_OK ) goto out;
 		if ( debug_set( &read_params ) ) bibl_verbose( b, "post_convert_refs", "for bibl_read" );
 	}
 	
 	else {
+	  // REprintf("bibl_read: before convert_refs; read_params.output_raw is TRUE\n");
 	 	status = bibl_copy( b, &bin );
 	 	if ( status!=BIBL_OK ) goto out;
 	 	if ( debug_set( &read_params ) ) bibl_verbose( b, "post_bibl_copy", "for bibl_read" );
 	}
 
+	
+	// REprintf("bibl_read: before 'if' and uniquify_citekeys\n");
+  
 	if ( ( !read_params.output_raw ) || ( read_params.output_raw & BIBL_RAW_WITHMAKEREFID ) ) {
+	        // REprintf("bibl_read: before uniquify_citekeys\n");
 		status = uniqueify_citekeys( b );
 		if ( status!=BIBL_OK ) goto out;
 		if ( read_params.addcount ) {
@@ -923,11 +949,11 @@ bibl_read( bibl *b, FILE *fp, char *filename, param *p )
 		if ( debug_set( &read_params ) ) bibl_verbose( &bin, "post_uniqueify_citekeys", "for bibl_read" );
 	}
 
-//   REprintf("\nbibl_read: at end of bibl_read\n");
-//   // Georgi: for testing
-//   for(long i = 0; i < b->n; ++i) {
-//     fields_report_stderr( b->ref[i] );
-//   }
+	// // Georgi: for testing
+	// REprintf("\nbibl_read: at end of bibl_read\n");
+	// for(long i = 0; i < b->n; ++i) {
+	//   fields_report_stderr( b->ref[i] );
+	// }
 
 out:
 	bibl_free( &bin );
@@ -954,8 +980,8 @@ singlerefname( fields *reffields, long nref, int mode )
 	found = fields_find( reffields, "REFNUM", LEVEL_MAIN );
 	/* find new filename based on reference */
 	if ( found!=-1 ) {
-		sprintf( outfile,"%s.%s",(char*)fields_value(reffields,found,FIELDS_CHRP_NOUSE), suffix );
-	} else  sprintf( outfile,"%ld.%s",nref, suffix );
+	  snprintf( outfile, 2048, "%s.%s",(char*)fields_value(reffields,found,FIELDS_CHRP_NOUSE), suffix );
+	} else  snprintf( outfile, 2048,"%ld.%s",nref, suffix );
 	count = 0;
 	fp = fopen( outfile, "r" );
 	while ( fp ) {
@@ -963,8 +989,8 @@ singlerefname( fields *reffields, long nref, int mode )
 		count++;
 		if ( count==60000 ) return NULL;
 		if ( found!=-1 )
-			sprintf( outfile, "%s_%ld.%s", (char*)fields_value( reffields, found, FIELDS_CHRP_NOUSE ), count, suffix );
-		else sprintf( outfile,"%ld_%ld.%s", nref, count, suffix );
+			snprintf( outfile, 2048, "%s_%ld.%s", (char*)fields_value( reffields, found, FIELDS_CHRP_NOUSE ), count, suffix );
+		else snprintf( outfile, 2048, "%ld_%ld.%s", nref, count, suffix );
 		fp = fopen( outfile, "r" );
 	}
 	return fopen( outfile, "w" );
